pub trait QueueOnDemandOrders<RelayBlockNumber> {
// Required method
fn queue_batch(batch: Vec<(TaskId, RelayBlockNumber)>);
}Expand description
Instructs the Relay chain to enqueue a batch of on-demand orders.
On the Coretime chain this is implemented by sending an XCM Transact to the Relay chain’s
coretime pallet.
Required Methods
Sourcefn queue_batch(batch: Vec<(TaskId, RelayBlockNumber)>)
fn queue_batch(batch: Vec<(TaskId, RelayBlockNumber)>)
Enqueue batch on the Relay chain.
Each entry is the parachain the order was placed for and the Relay-chain block number it was ordered at.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.