referrerpolicy=no-referrer-when-downgrade

PriceParametersOf

Type Alias PriceParametersOf 

pub type PriceParametersOf<T> = PriceParameters<BalanceOf<T>>;

Aliased Type

pub struct PriceParametersOf<T> {
    pub order_cap: u32,
    pub drain_rate_per_block: u32,
    pub price_step: Perbill,
    pub base_fee: <<T as Config>::Currency as Inspect<<T as Config>::AccountId>>::Balance,
}

Fields

order_cap: u32

The maximum number of outstanding orders beyond which we reject new orders.

drain_rate_per_block: u32

The number of outstanding orders assumed to be drained per Relay-chain block, per pool core.

price_step: Perbill

The spot price increase per outstanding order in the queue.

base_fee: <<T as Config>::Currency as Inspect<<T as Config>::AccountId>>::Balance

The base spot price when the queue is empty.